==> haskell-hinotify-0.4.1-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hinotify
version:              0.4.1
visibility:           public
id:                   hinotify-0.4.1-JMw33S3x3eABEVInGeoMlM
key:                  hinotify-0.4.1-JMw33S3x3eABEVInGeoMlM
license:              BSD-3-Clause
maintainer:           Lennart Kolmodin <kolmodin@gmail.com>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  a2a8242afcd99437b5c9879ca40c9977
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hinotify-0.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hinotify-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.1-JMw33S3x3eABEVInGeoMlM
includes:             sys/inotify.h
depends:
    async-2.2.4-8fHP2vwSLWH996zJYB8hGm base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hinotify-0.4.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hinotify
version:              0.4.1
visibility:           public
id:                   hinotify-0.4.1-A18EI1FiSco2oPbOUCl9FC
key:                  hinotify-0.4.1-A18EI1FiSco2oPbOUCl9FC
license:              BSD-3-Clause
maintainer:           Lennart Kolmodin <kolmodin@gmail.com>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  0a3060cd09863cb64fd67ed6bd573ba1
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hinotify-0.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hinotify-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.1-A18EI1FiSco2oPbOUCl9FC
includes:             sys/inotify.h
depends:
    async-2.2.4-17F2m0fMLmE9RexONjnSWz base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
